#! /usr/bin/python
# -*- Mode: Python -*-
# vi:si:et:sw=4:sts=4:ts=4

from buildbot.process import step
from buildbot.status.builder import SUCCESS, WARNINGS, FAILURE, SKIPPED

class IncMake(step.ShellCommand):
    name = "incmake"
    description = ["running",  "incr", "make"]
    descriptionDone = ["incr", "make"]
    command = ["make"]

class AutogenAfterIncMake(step.ShellCommand):
    name = "autogen"
    #warnOnFailure = 0
    haltOnFailure = 1
    description = ["autogenning"]
    descriptionDone = ["autogen"]
    command = ["./autogen.sh"]

    def start(self, errorMessage=None):
       previousResult = self.build.results[-1]
       # if the inc make succeeded, we don't need to autogen
       if previousResult == SUCCESS:
           return SKIPPED
       # otherwise, do what we would normally do
       return step.ShellCommand.start(self, errorMessage)

class CompileAfterIncMake(step.ShellCommand):
    name = "compile"
    #warnOnFailure = 0
    haltOnFailure = 1
    description = ["compiling"]
    descriptionDone = ["compile"]
    command = ["make"]

    def start(self, errorMessage=None):
       previousResult = self.build.results[-1]
       # if the autogen was skipped, we don't need to compile, since inc make
       # worked
       if previousResult == SKIPPED:
           return SKIPPED
       # otherwise, do what we would normally do
       return step.ShellCommand.start(self, errorMessage)

class Make(step.ShellCommand):
    def __init__(self, **kwargs):
        target = "all"
        if "target" in kwargs.keys():
            target = kwargs['target']
            del kwargs['target']

        # set defaults if not given for some vars
        for key, value in [
            ('name',        target),
            ('description',   ["running", "make " + target]),
            ('descriptionDone', ["make" + target]),
            ('command',        ["make", target])]:
            if not key in kwargs.keys():
                kwargs[key] = value

        step.ShellCommand.__init__(self, **kwargs)


